==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
var WebTabDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabDescriptionMetadata, _super);
    function WebTabDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabDescriptionMetadata.b = function (a) {
        if (WebTabDescriptionMetadata.a == null) {
            WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
        }
        if (a.g(WebTabDescriptionMetadata.a)) {
            return;
        }
        a.s(WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tab");
        a.item("Panel", "String");
        a.item("Selected", "Boolean");
        a.item("Disabled", "Boolean");
    };
    WebTabDescriptionMetadata.d = function (a) {
        WebTabDescriptionMetadata.b(a);
        a.u("WebTab", function () { return new WebTabDescription(); });
        a.t("WebTab", WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.$t = markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
}(Base));
export { WebTabDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebTabDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescription } from "./WebTabDescription";
/**
 * @hidden
 */
var WebTabDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabDescriptionMetadata, _super);
    function WebTabDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabDescriptionMetadata.b = function (a) {
        if (WebTabDescriptionMetadata.a == null) {
            WebTabDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabDescriptionMetadata.c(WebTabDescriptionMetadata.a);
        }
        if (a.j(WebTabDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Tab");
        a.item("__tagNameWC", "String:igc-tab");
        a.item("Panel", "String");
        a.item("Selected", "Boolean");
        a.item("Disabled", "Boolean");
    };
    WebTabDescriptionMetadata.d = function (a) {
        WebTabDescriptionMetadata.b(a);
        a.aa("WebTab", function () { return new WebTabDescription(); });
        a.z("WebTab", WebTabDescriptionMetadata.a);
    };
    WebTabDescriptionMetadata.$t = markType(WebTabDescriptionMetadata, 'WebTabDescriptionMetadata');
    WebTabDescriptionMetadata.a = null;
    return WebTabDescriptionMetadata;
}(Base));
export { WebTabDescriptionMetadata };
